# Table of Contents

- [add-organizations](<./add-organizations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Add Organizations](<./Add-Organizations.md>)
  - [Introduction to Organizations](<./Add-Organizations/Introduction-to-Organizations.md>)
  - [Required Attributes](<./Add-Organizations/Required-Attributes.md>)
  - [Define Organizations](<./Add-Organizations/Define-Organizations.md>)
  - [Add Organizations](<./Add-Organizations/Add-Organizations.md>)
  - [Monitor Progress Using Metrics](<./Add-Organizations/Monitor-Progress-Using-Metrics.md>)
  - [Was this page helpful?](<./Add-Organizations/Was-this-page-helpful.md>)
